from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Visualization(_message.Message):
    __slots__ = ("id", "computation_id", "result_observation_id", "type", "state", "metadata", "observation_metadata", "access_info", "created_on", "updated_on", "visualizer_config_id", "data_type_name")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_TYPE: _ClassVar[Visualization.Type]
        STANDARD: _ClassVar[Visualization.Type]
        SPATIAL: _ClassVar[Visualization.Type]
        TEMPORAL: _ClassVar[Visualization.Type]
        RASTER: _ClassVar[Visualization.Type]
        VIDEO_JSON: _ClassVar[Visualization.Type]
    UNKNOWN_TYPE: Visualization.Type
    STANDARD: Visualization.Type
    SPATIAL: Visualization.Type
    TEMPORAL: Visualization.Type
    RASTER: Visualization.Type
    VIDEO_JSON: Visualization.Type
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATE: _ClassVar[Visualization.State]
        NEW: _ClassVar[Visualization.State]
        QUEUED: _ClassVar[Visualization.State]
        VALIDATING: _ClassVar[Visualization.State]
        EMPTY: _ClassVar[Visualization.State]
        UPLOADED: _ClassVar[Visualization.State]
        FAILED: _ClassVar[Visualization.State]
        DELETING: _ClassVar[Visualization.State]
        DELETED: _ClassVar[Visualization.State]
    UNKNOWN_STATE: Visualization.State
    NEW: Visualization.State
    QUEUED: Visualization.State
    VALIDATING: Visualization.State
    EMPTY: Visualization.State
    UPLOADED: Visualization.State
    FAILED: Visualization.State
    DELETING: Visualization.State
    DELETED: Visualization.State
    class AccessInfo(_message.Message):
        __slots__ = ("url_template", "credentials")
        URL_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
        CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
        url_template: str
        credentials: _struct_pb2.Struct
        def __init__(self, url_template: _Optional[str] = ..., credentials: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    COMPUTATION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_OBSERVATION_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    OBSERVATION_METADATA_FIELD_NUMBER: _ClassVar[int]
    ACCESS_INFO_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    UPDATED_ON_FIELD_NUMBER: _ClassVar[int]
    VISUALIZER_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    computation_id: str
    result_observation_id: str
    type: Visualization.Type
    state: Visualization.State
    metadata: _struct_pb2.Struct
    observation_metadata: _struct_pb2.Struct
    access_info: Visualization.AccessInfo
    created_on: _timestamp_pb2.Timestamp
    updated_on: _timestamp_pb2.Timestamp
    visualizer_config_id: str
    data_type_name: str
    def __init__(self, id: _Optional[str] = ..., computation_id: _Optional[str] = ..., result_observation_id: _Optional[str] = ..., type: _Optional[_Union[Visualization.Type, str]] = ..., state: _Optional[_Union[Visualization.State, str]] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., observation_metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., access_info: _Optional[_Union[Visualization.AccessInfo, _Mapping]] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., visualizer_config_id: _Optional[str] = ..., data_type_name: _Optional[str] = ...) -> None: ...

class VisualizationGetRequest(_message.Message):
    __slots__ = ("result_observation_ids",)
    RESULT_OBSERVATION_IDS_FIELD_NUMBER: _ClassVar[int]
    result_observation_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, result_observation_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class VisualizationGetResponse(_message.Message):
    __slots__ = ("status_code", "visualizations", "base_url_template")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    VISUALIZATIONS_FIELD_NUMBER: _ClassVar[int]
    BASE_URL_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    visualizations: _containers.RepeatedCompositeFieldContainer[Visualization]
    base_url_template: str
    def __init__(self, status_code: _Optional[int] = ..., visualizations: _Optional[_Iterable[_Union[Visualization, _Mapping]]] = ..., base_url_template: _Optional[str] = ...) -> None: ...

class Visualizer(_message.Message):
    __slots__ = ("id", "name", "visualizer_type", "data_types")
    class VisualizerType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_VISUALIZER_TYPE: _ClassVar[Visualizer.VisualizerType]
        KEPLER: _ClassVar[Visualizer.VisualizerType]
        OI_VISUALIZATION_SERVICE: _ClassVar[Visualizer.VisualizerType]
        UI_TERRASCOPE_RESULTS: _ClassVar[Visualizer.VisualizerType]
    UNKNOWN_VISUALIZER_TYPE: Visualizer.VisualizerType
    KEPLER: Visualizer.VisualizerType
    OI_VISUALIZATION_SERVICE: Visualizer.VisualizerType
    UI_TERRASCOPE_RESULTS: Visualizer.VisualizerType
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VISUALIZER_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPES_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    visualizer_type: Visualizer.VisualizerType
    data_types: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., visualizer_type: _Optional[_Union[Visualizer.VisualizerType, str]] = ..., data_types: _Optional[_Iterable[str]] = ...) -> None: ...

class VisualizerConfig(_message.Message):
    __slots__ = ("id", "config", "visualizer")
    ID_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    VISUALIZER_FIELD_NUMBER: _ClassVar[int]
    id: str
    config: _struct_pb2.Struct
    visualizer: Visualizer
    def __init__(self, id: _Optional[str] = ..., config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., visualizer: _Optional[_Union[Visualizer, _Mapping]] = ...) -> None: ...

class VisualizerConfigAlgoVersionCreateRequest(_message.Message):
    __slots__ = ("visualizer_config_id", "algorithm_version_id")
    VISUALIZER_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    visualizer_config_id: str
    algorithm_version_id: str
    def __init__(self, visualizer_config_id: _Optional[str] = ..., algorithm_version_id: _Optional[str] = ...) -> None: ...

class VisualizerConfigAlgoVersionCreateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class VisualizerConfigAlgoGetRequest(_message.Message):
    __slots__ = ("algorithm_config_ids",)
    ALGORITHM_CONFIG_IDS_FIELD_NUMBER: _ClassVar[int]
    algorithm_config_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, algorithm_config_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class VisualizerConfigAlgo(_message.Message):
    __slots__ = ("algorithm_version_id", "visualizer_configs", "algorithm_config_id")
    ALGORITHM_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    VISUALIZER_CONFIGS_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    algorithm_version_id: str
    visualizer_configs: _containers.RepeatedCompositeFieldContainer[VisualizerConfig]
    algorithm_config_id: str
    def __init__(self, algorithm_version_id: _Optional[str] = ..., visualizer_configs: _Optional[_Iterable[_Union[VisualizerConfig, _Mapping]]] = ..., algorithm_config_id: _Optional[str] = ...) -> None: ...

class VisualizerConfigAlgoGetResponse(_message.Message):
    __slots__ = ("status_code", "visualizer_config_algos")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    VISUALIZER_CONFIG_ALGOS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    visualizer_config_algos: _containers.RepeatedCompositeFieldContainer[VisualizerConfigAlgo]
    def __init__(self, status_code: _Optional[int] = ..., visualizer_config_algos: _Optional[_Iterable[_Union[VisualizerConfigAlgo, _Mapping]]] = ...) -> None: ...

class VisualizerConfigAlgoConfigCreateRequest(_message.Message):
    __slots__ = ("visualizer_config_id", "algorithm_config_id")
    VISUALIZER_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    visualizer_config_id: str
    algorithm_config_id: str
    def __init__(self, visualizer_config_id: _Optional[str] = ..., algorithm_config_id: _Optional[str] = ...) -> None: ...

class VisualizerConfigAlgoConfigCreateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: resource.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'resource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import subject_pb2 as subject__pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.subject_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eresource.proto\x12\x12oi.papi.permission\x1a\x13\x63ommon_models.proto\x1a\rsubject.proto\"+\n\x1bResourceRegisterTypeRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"[\n\x1cResourceRegisterTypeResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\x12\x17\n\x0f\x61lready_existed\x18\x03 \x01(\x08\"F\n\x18ResourceTypesListRequest\x12\r\n\x05value\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05regex\x18\x03 \x01(\x08\"\xa3\x01\n\x19ResourceTypesListResponse\x12S\n\x0ctype_to_name\x18\x01 \x03(\x0b\x32=.oi.papi.permission.ResourceTypesListResponse.TypeToNameEntry\x1a\x31\n\x0fTypeToNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x03\n\x08Resource\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.oi.papi.permission.Resource.Type\"\xea\x02\n\x04Type\x12$\n PERMISSION_RESOURCE_TYPE_UNKNOWN\x10\x00\x12\r\n\tALGORITHM\x10\x01\x12\x19\n\x15\x41LGORITHM_COMPUTATION\x10\x02\x12\x14\n\x10\x41LGORITHM_CONFIG\x10\x03\x12\x0c\n\x08\x41NALYSIS\x10\x04\x12\x18\n\x14\x41NALYSIS_COMPUTATION\x10\x05\x12\x13\n\x0f\x41NALYSIS_CONFIG\x10\x06\x12\x12\n\x0e\x41OI_COLLECTION\x10\x07\x12\n\n\x06RESULT\x10\x08\x12\x07\n\x03TOI\x10\t\x12\x17\n\x12\x44IRECT_RANGE_START\x10\xe8\x07\x12\x10\n\x0b\x44\x41TA_SOURCE\x10\xf2\x07\x12\x11\n\x0c\x44\x41TA_SOURCES\x10\xf3\x07\x12\x1c\n\x17\x41PPLICATION_RANGE_START\x10\xd0\x0f\x12\x1a\n\x15MOBILE_WORKFORCE_TASK\x10\xb4\x10\x12\x1e\n\x19MOBILE_WORKFORCE_CAMPAIGN\x10\xb5\x10\"v\n\x15ResourceCreateRequest\x12/\n\tresources\x18\x01 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\x12,\n\x06parent\x18\x02 \x01(\x0b\x32\x1c.oi.papi.permission.Resource\"o\n\x16ResourceCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12/\n\tresources\x18\x02 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xbc\x01\n\x13ResourceListRequest\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.oi.papi.permission.Resource.Type\x12\x18\n\x10permission_types\x18\x02 \x03(\r\x12,\n\x06parent\x18\x03 \x01(\x0b\x32\x1c.oi.papi.permission.Resource\x12,\n\x07subject\x18\x04 \x01(\x0b\x32\x1b.oi.papi.permission.Subject\"\\\n\x14ResourceListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12/\n\tresources\x18\x02 \x03(\x0b\x32\x1c.oi.papi.permission.Resource2\xa3\x03\n\x0bResourceApi\x12m\n\x08register\x12/.oi.papi.permission.ResourceRegisterTypeRequest\x1a\x30.oi.papi.permission.ResourceRegisterTypeResponse\x12_\n\x06\x63reate\x12).oi.papi.permission.ResourceCreateRequest\x1a*.oi.papi.permission.ResourceCreateResponse\x12Y\n\x04list\x12\'.oi.papi.permission.ResourceListRequest\x1a(.oi.papi.permission.ResourceListResponse\x12i\n\nlist_types\x12,.oi.papi.permission.ResourceTypesListRequest\x1a-.oi.papi.permission.ResourceTypesListResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'resource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESOURCETYPESLISTRESPONSE_TYPETONAMEENTRY']._loaded_options = None
  _globals['_RESOURCETYPESLISTRESPONSE_TYPETONAMEENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCEREGISTERTYPEREQUEST']._serialized_start=74
  _globals['_RESOURCEREGISTERTYPEREQUEST']._serialized_end=117
  _globals['_RESOURCEREGISTERTYPERESPONSE']._serialized_start=119
  _globals['_RESOURCEREGISTERTYPERESPONSE']._serialized_end=210
  _globals['_RESOURCETYPESLISTREQUEST']._serialized_start=212
  _globals['_RESOURCETYPESLISTREQUEST']._serialized_end=282
  _globals['_RESOURCETYPESLISTRESPONSE']._serialized_start=285
  _globals['_RESOURCETYPESLISTRESPONSE']._serialized_end=448
  _globals['_RESOURCETYPESLISTRESPONSE_TYPETONAMEENTRY']._serialized_start=399
  _globals['_RESOURCETYPESLISTRESPONSE_TYPETONAMEENTRY']._serialized_end=448
  _globals['_RESOURCE']._serialized_start=451
  _globals['_RESOURCE']._serialized_end=887
  _globals['_RESOURCE_TYPE']._serialized_start=525
  _globals['_RESOURCE_TYPE']._serialized_end=887
  _globals['_RESOURCECREATEREQUEST']._serialized_start=889
  _globals['_RESOURCECREATEREQUEST']._serialized_end=1007
  _globals['_RESOURCECREATERESPONSE']._serialized_start=1009
  _globals['_RESOURCECREATERESPONSE']._serialized_end=1120
  _globals['_RESOURCELISTREQUEST']._serialized_start=1123
  _globals['_RESOURCELISTREQUEST']._serialized_end=1311
  _globals['_RESOURCELISTRESPONSE']._serialized_start=1313
  _globals['_RESOURCELISTRESPONSE']._serialized_end=1405
  _globals['_RESOURCEAPI']._serialized_start=1408
  _globals['_RESOURCEAPI']._serialized_end=1827
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import data_type_pb2 as data__type__pb2

GRPC_GENERATED_VERSION = '1.68.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in data_type_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DataTypeAPIStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.DataTypeAPI/create',
                request_serializer=data__type__pb2.DataTypeCreateRequest.SerializeToString,
                response_deserializer=data__type__pb2.DataTypeCreateResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.DataTypeAPI/get',
                request_serializer=data__type__pb2.DataTypeGetRequest.SerializeToString,
                response_deserializer=data__type__pb2.DataTypeGetResponse.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/oi.papi.DataTypeAPI/list',
                request_serializer=data__type__pb2.DataTypeListRequest.SerializeToString,
                response_deserializer=data__type__pb2.DataTypeListResponse.FromString,
                _registered_method=True)


class DataTypeAPIServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Creates a new DataType.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Gets a DataType that the user has access to.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        List all registered DataType.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataTypeAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=data__type__pb2.DataTypeCreateRequest.FromString,
                    response_serializer=data__type__pb2.DataTypeCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=data__type__pb2.DataTypeGetRequest.FromString,
                    response_serializer=data__type__pb2.DataTypeGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=data__type__pb2.DataTypeListRequest.FromString,
                    response_serializer=data__type__pb2.DataTypeListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.DataTypeAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.DataTypeAPI', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DataTypeAPI(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataTypeAPI/create',
            data__type__pb2.DataTypeCreateRequest.SerializeToString,
            data__type__pb2.DataTypeCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataTypeAPI/get',
            data__type__pb2.DataTypeGetRequest.SerializeToString,
            data__type__pb2.DataTypeGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.DataTypeAPI/list',
            data__type__pb2.DataTypeListRequest.SerializeToString,
            data__type__pb2.DataTypeListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: algorithm_config.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'algorithm_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import algorithm_pb2 as algorithm__pb2
try:
  common__models__pb2 = algorithm__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__pb2.common_models_pb2
from terrascope_api.models import algorithm_version_pb2 as algorithm__version__pb2
try:
  common__models__pb2 = algorithm__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__version__pb2.common_models_pb2
try:
  algorithm__pb2 = algorithm__version__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = algorithm__version__pb2.algorithm_pb2
try:
  common__models__pb2 = algorithm__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__version__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.algorithm_pb2 import *
from terrascope_api.models.algorithm_version_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61lgorithm_config.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0f\x61lgorithm.proto\x1a\x17\x61lgorithm_version.proto\"\xbf\x02\n\x0f\x41lgorithmConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x11\x61lgorithm_version\x18\x02 \x01(\x0b\x32\x19.oi.papi.AlgorithmVersion\x12\'\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\talgorithm\x18\x04 \x01(\x0b\x32\x12.oi.papi.Algorithm\x12.\n\ncreated_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0eis_deactivated\x18\x06 \x01(\x08\x12\x15\n\ris_deprecated\x18\x07 \x01(\x08\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x18\n\x10resources_locked\x18\n \x01(\x08\"\x88\x01\n\x1c\x41lgorithmConfigCreateRequest\x12\x1c\n\x14\x61lgorithm_version_id\x18\x01 \x01(\t\x12\'\n\x06params\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"h\n\x1d\x41lgorithmConfigCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x32\n\x10\x61lgorithm_config\x18\x02 \x01(\x0b\x32\x18.oi.papi.AlgorithmConfig\"]\n\x1c\x41lgorithmConfigUpdateRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x31\n\x10\x61lgorithm_config\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"4\n\x1d\x41lgorithmConfigUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\x85\x01\n\x19\x41lgorithmConfigGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x14\n\x0c\x61lgorithm_id\x18\x02 \x01(\t\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x1c\n\x14\x61lgorithm_version_id\x18\x04 \x01(\t\"\x8f\x01\n\x1a\x41lgorithmConfigGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x33\n\x11\x61lgorithm_configs\x18\x02 \x03(\x0b\x32\x18.oi.papi.AlgorithmConfig\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x93\x02\n\x1a\x41lgorithmConfigListRequest\x12\x14\n\x0c\x61lgorithm_id\x18\x01 \x01(\t\x12\x1c\n\x14\x61lgorithm_version_id\x18\x02 \x01(\t\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x32\n\x0emin_created_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13include_deactivated\x18\x06 \x01(\x08\x12\'\n\npagination\x18\x07 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x90\x01\n\x1b\x41lgorithmConfigListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x33\n\x11\x61lgorithm_configs\x18\x02 \x03(\x0b\x32\x18.oi.papi.AlgorithmConfig\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"+\n\x1c\x41lgorithmConfigDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"4\n\x1d\x41lgorithmConfigDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\".\n\x1f\x41lgorithmConfigDeprecateRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"7\n AlgorithmConfigDeprecateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"/\n AlgorithmConfigDeactivateRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"8\n!AlgorithmConfigDeactivateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\x89\x05\n\x12\x41lgorithmConfigApi\x12W\n\x06\x63reate\x12%.oi.papi.AlgorithmConfigCreateRequest\x1a&.oi.papi.AlgorithmConfigCreateResponse\x12N\n\x03get\x12\".oi.papi.AlgorithmConfigGetRequest\x1a#.oi.papi.AlgorithmConfigGetResponse\x12Q\n\x04list\x12#.oi.papi.AlgorithmConfigListRequest\x1a$.oi.papi.AlgorithmConfigListResponse\x12W\n\x06update\x12%.oi.papi.AlgorithmConfigUpdateRequest\x1a&.oi.papi.AlgorithmConfigUpdateResponse\x12`\n\tdeprecate\x12(.oi.papi.AlgorithmConfigDeprecateRequest\x1a).oi.papi.AlgorithmConfigDeprecateResponse\x12\x63\n\ndeactivate\x12).oi.papi.AlgorithmConfigDeactivateRequest\x1a*.oi.papi.AlgorithmConfigDeactivateResponse\x12W\n\x06\x64\x65lete\x12%.oi.papi.AlgorithmConfigDeleteRequest\x1a&.oi.papi.AlgorithmConfigDeleteResponseP\x01P\x03P\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'algorithm_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ALGORITHMCONFIG']._serialized_start=162
  _globals['_ALGORITHMCONFIG']._serialized_end=481
  _globals['_ALGORITHMCONFIGCREATEREQUEST']._serialized_start=484
  _globals['_ALGORITHMCONFIGCREATEREQUEST']._serialized_end=620
  _globals['_ALGORITHMCONFIGCREATERESPONSE']._serialized_start=622
  _globals['_ALGORITHMCONFIGCREATERESPONSE']._serialized_end=726
  _globals['_ALGORITHMCONFIGUPDATEREQUEST']._serialized_start=728
  _globals['_ALGORITHMCONFIGUPDATEREQUEST']._serialized_end=821
  _globals['_ALGORITHMCONFIGUPDATERESPONSE']._serialized_start=823
  _globals['_ALGORITHMCONFIGUPDATERESPONSE']._serialized_end=875
  _globals['_ALGORITHMCONFIGGETREQUEST']._serialized_start=878
  _globals['_ALGORITHMCONFIGGETREQUEST']._serialized_end=1011
  _globals['_ALGORITHMCONFIGGETRESPONSE']._serialized_start=1014
  _globals['_ALGORITHMCONFIGGETRESPONSE']._serialized_end=1157
  _globals['_ALGORITHMCONFIGLISTREQUEST']._serialized_start=1160
  _globals['_ALGORITHMCONFIGLISTREQUEST']._serialized_end=1435
  _globals['_ALGORITHMCONFIGLISTRESPONSE']._serialized_start=1438
  _globals['_ALGORITHMCONFIGLISTRESPONSE']._serialized_end=1582
  _globals['_ALGORITHMCONFIGDELETEREQUEST']._serialized_start=1584
  _globals['_ALGORITHMCONFIGDELETEREQUEST']._serialized_end=1627
  _globals['_ALGORITHMCONFIGDELETERESPONSE']._serialized_start=1629
  _globals['_ALGORITHMCONFIGDELETERESPONSE']._serialized_end=1681
  _globals['_ALGORITHMCONFIGDEPRECATEREQUEST']._serialized_start=1683
  _globals['_ALGORITHMCONFIGDEPRECATEREQUEST']._serialized_end=1729
  _globals['_ALGORITHMCONFIGDEPRECATERESPONSE']._serialized_start=1731
  _globals['_ALGORITHMCONFIGDEPRECATERESPONSE']._serialized_end=1786
  _globals['_ALGORITHMCONFIGDEACTIVATEREQUEST']._serialized_start=1788
  _globals['_ALGORITHMCONFIGDEACTIVATEREQUEST']._serialized_end=1835
  _globals['_ALGORITHMCONFIGDEACTIVATERESPONSE']._serialized_start=1837
  _globals['_ALGORITHMCONFIGDEACTIVATERESPONSE']._serialized_end=1893
  _globals['_ALGORITHMCONFIGAPI']._serialized_start=1896
  _globals['_ALGORITHMCONFIGAPI']._serialized_end=2545
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: provider_quotas.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'provider_quotas.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15provider_quotas.proto\x12\x0eoi.papi.quotas\"-\n\x19ProviderQuotasListRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\"f\n\rProviderQuota\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x12\n\nquota_name\x18\x02 \x01(\t\x12\x0c\n\x04used\x18\x03 \x01(\x02\x12\r\n\x05limit\x18\x04 \x01(\x02\x12\x0c\n\x04unit\x18\x05 \x01(\t\"K\n\x1aProviderQuotasListResponse\x12-\n\x06quotas\x18\x01 \x03(\x0b\x32\x1d.oi.papi.quotas.ProviderQuota2r\n\x11ProviderQuotasApi\x12]\n\x04list\x12).oi.papi.quotas.ProviderQuotasListRequest\x1a*.oi.papi.quotas.ProviderQuotasListResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'provider_quotas_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROVIDERQUOTASLISTREQUEST']._serialized_start=41
  _globals['_PROVIDERQUOTASLISTREQUEST']._serialized_end=86
  _globals['_PROVIDERQUOTA']._serialized_start=88
  _globals['_PROVIDERQUOTA']._serialized_end=190
  _globals['_PROVIDERQUOTASLISTRESPONSE']._serialized_start=192
  _globals['_PROVIDERQUOTASLISTRESPONSE']._serialized_end=267
  _globals['_PROVIDERQUOTASAPI']._serialized_start=269
  _globals['_PROVIDERQUOTASAPI']._serialized_end=383
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import user_collection_pb2 as user__collection__pb2

GRPC_GENERATED_VERSION = '1.68.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in user_collection_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UserCollectionApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.UserCollectionApi/create',
                request_serializer=user__collection__pb2.UserCollectionCreateRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionCreateResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.UserCollectionApi/get',
                request_serializer=user__collection__pb2.UserCollectionGetRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionGetResponse.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/oi.papi.UserCollectionApi/list',
                request_serializer=user__collection__pb2.UserCollectionListRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionListResponse.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/oi.papi.UserCollectionApi/update',
                request_serializer=user__collection__pb2.UserCollectionUpdateRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionUpdateResponse.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/oi.papi.UserCollectionApi/delete',
                request_serializer=user__collection__pb2.UserCollectionDeleteRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionDeleteResponse.FromString,
                _registered_method=True)
        self.add_user = channel.unary_unary(
                '/oi.papi.UserCollectionApi/add_user',
                request_serializer=user__collection__pb2.UserCollectionAddUserRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionAddUserResponse.FromString,
                _registered_method=True)
        self.remove_user = channel.unary_unary(
                '/oi.papi.UserCollectionApi/remove_user',
                request_serializer=user__collection__pb2.UserCollectionRemoveUserRequest.SerializeToString,
                response_deserializer=user__collection__pb2.UserCollectionRemoveUserResponse.FromString,
                _registered_method=True)


class UserCollectionApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create a new UserCollection to house a collection of users. This can only be done by an admin.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get the details of a UserCollection. This can only done for the UserCollection that a User is a part of.
        If include_users is set to true, this endpoint also returns the list of Users in the UserCollection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        Search for collections
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        Update a UserCollection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        Delete a UserCollection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def add_user(self, request, context):
        """
        Add a User to UserCollection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def remove_user(self, request, context):
        """
        Remove a User from UserCollection
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserCollectionApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=user__collection__pb2.UserCollectionCreateRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionCreateResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=user__collection__pb2.UserCollectionGetRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=user__collection__pb2.UserCollectionListRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionListResponse.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=user__collection__pb2.UserCollectionUpdateRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionUpdateResponse.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=user__collection__pb2.UserCollectionDeleteRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionDeleteResponse.SerializeToString,
            ),
            'add_user': grpc.unary_unary_rpc_method_handler(
                    servicer.add_user,
                    request_deserializer=user__collection__pb2.UserCollectionAddUserRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionAddUserResponse.SerializeToString,
            ),
            'remove_user': grpc.unary_unary_rpc_method_handler(
                    servicer.remove_user,
                    request_deserializer=user__collection__pb2.UserCollectionRemoveUserRequest.FromString,
                    response_serializer=user__collection__pb2.UserCollectionRemoveUserResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.UserCollectionApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.UserCollectionApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserCollectionApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserCollectionApi/create',
            user__collection__pb2.UserCollectionCreateRequest.SerializeToString,
            user__collection__pb2.UserCollectionCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserCollectionApi/get',
            user__collection__pb2.UserCollectionGetRequest.SerializeToString,
            user__collection__pb2.UserCollectionGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserCollectionApi/list',
            user__collection__pb2.UserCollectionListRequest.SerializeToString,
            user__collection__pb2.UserCollectionListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserCollectionApi/update',
            user__collection__pb2.UserCollectionUpdateRequest.SerializeToString,
            user__collection__pb2.UserCollectionUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserCollectionApi/delete',
            user__collection__pb2.UserCollectionDeleteRequest.SerializeToString,
            user__collection__pb2.UserCollectionDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def add_user(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserCollectionApi/add_user',
            user__collection__pb2.UserCollectionAddUserRequest.SerializeToString,
            user__collection__pb2.UserCollectionAddUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def remove_user(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.UserCollectionApi/remove_user',
            user__collection__pb2.UserCollectionRemoveUserRequest.SerializeToString,
            user__collection__pb2.UserCollectionRemoveUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: permission.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'permission.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import resource_pb2 as resource__pb2
try:
  common__models__pb2 = resource__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = resource__pb2.common_models_pb2
try:
  subject__pb2 = resource__pb2.subject__pb2
except AttributeError:
  subject__pb2 = resource__pb2.subject_pb2
from terrascope_api.models import subject_pb2 as subject__pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.resource_pb2 import *
from terrascope_api.models.subject_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10permission.proto\x12\x12oi.papi.permission\x1a\x13\x63ommon_models.proto\x1a\x0eresource.proto\x1a\rsubject.proto\"\x9c\x02\n\nPermission\x12-\n\x08subjects\x18\x03 \x03(\x0b\x32\x1b.oi.papi.permission.Subject\x12=\n\x10permission_types\x18\x04 \x03(\x0e\x32#.oi.papi.permission.Permission.Type\x12/\n\tresources\x18\x05 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\"o\n\x04Type\x12\x1b\n\x17PERMISSION_TYPE_UNKNOWN\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\x12\x0b\n\x07\x45XECUTE\x10\x04\x12\t\n\x05ORDER\x10\x05\x12\x12\n\x0eORDER_APPROVER\x10\x06\"N\n\x17PermissionCreateRequest\x12\x33\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1e.oi.papi.permission.Permission\"@\n\x18PermissionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\"N\n\x17PermissionDeleteRequest\x12\x33\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1e.oi.papi.permission.Permission\"@\n\x18PermissionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xb3\x01\n\x14PermissionGetRequest\x12/\n\tresources\x18\x01 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\x12<\n\x0fpermission_type\x18\x02 \x01(\x0e\x32#.oi.papi.permission.Permission.Type\x12,\n\x07subject\x18\x03 \x01(\x0b\x32\x1b.oi.papi.permission.Subject\",\n\x15PermissionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\xb5\x01\n\x15PermissionListRequest\x12/\n\tresources\x18\x01 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\x12=\n\x10permission_types\x18\x02 \x03(\x0e\x32#.oi.papi.permission.Permission.Type\x12,\n\x07subject\x18\x03 \x01(\x0b\x32\x1b.oi.papi.permission.Subject\"\x7f\n\x0ePermissionList\x12<\n\x0fpermission_type\x18\x01 \x01(\x0e\x32#.oi.papi.permission.Permission.Type\x12/\n\tresources\x18\x02 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\"s\n\x16PermissionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x44\n\x18permission_and_resources\x18\x02 \x03(\x0b\x32\".oi.papi.permission.PermissionList\"\xde\x04\n\x18PermissionSystemMetadata\x12\x62\n\x17resource_types_metadata\x18\x01 \x03(\x0b\x32\x41.oi.papi.permission.PermissionSystemMetadata.ResourceTypeMetadata\x12\x66\n\x19permission_types_metadata\x18\x02 \x03(\x0b\x32\x43.oi.papi.permission.PermissionSystemMetadata.PermissionTypeMetadata\x12]\n\x14resource_permissions\x18\x03 \x03(\x0b\x32?.oi.papi.permission.PermissionSystemMetadata.ResourcePermission\x1a\\\n\x14ResourceTypeMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0b\n\x03ord\x18\x04 \x01(\x05\x1a^\n\x16PermissionTypeMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0b\n\x03ord\x18\x04 \x01(\x05\x1aY\n\x12ResourcePermission\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x17\n\x0fpermission_type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x1e\n\x1cPermissionGetMetadataRequest\"t\n\x1dPermissionGetMetadataResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12>\n\x08metadata\x18\x02 \x01(\x0b\x32,.oi.papi.permission.PermissionSystemMetadata2\x89\x04\n\rPermissionApi\x12\x63\n\x06\x63reate\x12+.oi.papi.permission.PermissionCreateRequest\x1a,.oi.papi.permission.PermissionCreateResponse\x12\x63\n\x06\x64\x65lete\x12+.oi.papi.permission.PermissionDeleteRequest\x1a,.oi.papi.permission.PermissionDeleteResponse\x12Z\n\x03get\x12(.oi.papi.permission.PermissionGetRequest\x1a).oi.papi.permission.PermissionGetResponse\x12]\n\x04list\x12).oi.papi.permission.PermissionListRequest\x1a*.oi.papi.permission.PermissionListResponse\x12s\n\x0cget_metadata\x12\x30.oi.papi.permission.PermissionGetMetadataRequest\x1a\x31.oi.papi.permission.PermissionGetMetadataResponseP\x00P\x01P\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'permission_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PERMISSION']._serialized_start=93
  _globals['_PERMISSION']._serialized_end=377
  _globals['_PERMISSION_TYPE']._serialized_start=266
  _globals['_PERMISSION_TYPE']._serialized_end=377
  _globals['_PERMISSIONCREATEREQUEST']._serialized_start=379
  _globals['_PERMISSIONCREATEREQUEST']._serialized_end=457
  _globals['_PERMISSIONCREATERESPONSE']._serialized_start=459
  _globals['_PERMISSIONCREATERESPONSE']._serialized_end=523
  _globals['_PERMISSIONDELETEREQUEST']._serialized_start=525
  _globals['_PERMISSIONDELETEREQUEST']._serialized_end=603
  _globals['_PERMISSIONDELETERESPONSE']._serialized_start=605
  _globals['_PERMISSIONDELETERESPONSE']._serialized_end=669
  _globals['_PERMISSIONGETREQUEST']._serialized_start=672
  _globals['_PERMISSIONGETREQUEST']._serialized_end=851
  _globals['_PERMISSIONGETRESPONSE']._serialized_start=853
  _globals['_PERMISSIONGETRESPONSE']._serialized_end=897
  _globals['_PERMISSIONLISTREQUEST']._serialized_start=900
  _globals['_PERMISSIONLISTREQUEST']._serialized_end=1081
  _globals['_PERMISSIONLIST']._serialized_start=1083
  _globals['_PERMISSIONLIST']._serialized_end=1210
  _globals['_PERMISSIONLISTRESPONSE']._serialized_start=1212
  _globals['_PERMISSIONLISTRESPONSE']._serialized_end=1327
  _globals['_PERMISSIONSYSTEMMETADATA']._serialized_start=1330
  _globals['_PERMISSIONSYSTEMMETADATA']._serialized_end=1936
  _globals['_PERMISSIONSYSTEMMETADATA_RESOURCETYPEMETADATA']._serialized_start=1657
  _globals['_PERMISSIONSYSTEMMETADATA_RESOURCETYPEMETADATA']._serialized_end=1749
  _globals['_PERMISSIONSYSTEMMETADATA_PERMISSIONTYPEMETADATA']._serialized_start=1751
  _globals['_PERMISSIONSYSTEMMETADATA_PERMISSIONTYPEMETADATA']._serialized_end=1845
  _globals['_PERMISSIONSYSTEMMETADATA_RESOURCEPERMISSION']._serialized_start=1847
  _globals['_PERMISSIONSYSTEMMETADATA_RESOURCEPERMISSION']._serialized_end=1936
  _globals['_PERMISSIONGETMETADATAREQUEST']._serialized_start=1938
  _globals['_PERMISSIONGETMETADATAREQUEST']._serialized_end=1968
  _globals['_PERMISSIONGETMETADATARESPONSE']._serialized_start=1970
  _globals['_PERMISSIONGETMETADATARESPONSE']._serialized_end=2086
  _globals['_PERMISSIONAPI']._serialized_start=2089
  _globals['_PERMISSIONAPI']._serialized_end=2610
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import algorithm_computation_pb2 as algorithm__computation__pb2

GRPC_GENERATED_VERSION = '1.68.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in algorithm_computation_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AlgorithmComputationApiStub(object):
    """*************************************************************
    Computation Interface
    *************************************************************

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.AlgorithmComputationApi/create',
                request_serializer=algorithm__computation__pb2.AlgorithmComputationCreateRequest.SerializeToString,
                response_deserializer=algorithm__computation__pb2.AlgorithmComputationCreateResponse.FromString,
                _registered_method=True)
        self.run = channel.unary_unary(
                '/oi.papi.AlgorithmComputationApi/run',
                request_serializer=algorithm__computation__pb2.AlgorithmComputationRunRequest.SerializeToString,
                response_deserializer=algorithm__computation__pb2.AlgorithmComputationRunResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.AlgorithmComputationApi/get',
                request_serializer=algorithm__computation__pb2.AlgorithmComputationGetRequest.SerializeToString,
                response_deserializer=algorithm__computation__pb2.AlgorithmComputationGetResponse.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/oi.papi.AlgorithmComputationApi/list',
                request_serializer=algorithm__computation__pb2.AlgorithmComputationListRequest.SerializeToString,
                response_deserializer=algorithm__computation__pb2.AlgorithmComputationListResponse.FromString,
                _registered_method=True)


class AlgorithmComputationApiServicer(object):
    """*************************************************************
    Computation Interface
    *************************************************************

    """

    def create(self, request, context):
        """
        Create the runnable component in the system, by specifying the AlgorithmConfig to be run,
        the set of AOIs to be run on, and the TOI. The algorithm_computation_id is returned so that it can be run.
        Note that until an algorithm_computation has been run, its underlying resources are NOT locked and therefore can be changed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def run(self, request, context):
        """
        The first time this endpoint is called, the system initiates the running of the provided algorithm_computation_id.
        This causes credits to be place in pending status and eventually consumed when the computation completes.
        Credits are consumed as each result is produced.
        Once an algorithm_computation has been run, it is considered locked and cannot be changed, as are its constituents.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Retrieves the details of the provided algorithm_computation including its current state and its progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        Lists the details for all AlgorithmComputations that the requester has access to including their current state and their progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlgorithmComputationApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=algorithm__computation__pb2.AlgorithmComputationCreateRequest.FromString,
                    response_serializer=algorithm__computation__pb2.AlgorithmComputationCreateResponse.SerializeToString,
            ),
            'run': grpc.unary_unary_rpc_method_handler(
                    servicer.run,
                    request_deserializer=algorithm__computation__pb2.AlgorithmComputationRunRequest.FromString,
                    response_serializer=algorithm__computation__pb2.AlgorithmComputationRunResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=algorithm__computation__pb2.AlgorithmComputationGetRequest.FromString,
                    response_serializer=algorithm__computation__pb2.AlgorithmComputationGetResponse.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=algorithm__computation__pb2.AlgorithmComputationListRequest.FromString,
                    response_serializer=algorithm__computation__pb2.AlgorithmComputationListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.AlgorithmComputationApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.AlgorithmComputationApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AlgorithmComputationApi(object):
    """*************************************************************
    Computation Interface
    *************************************************************

    """

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmComputationApi/create',
            algorithm__computation__pb2.AlgorithmComputationCreateRequest.SerializeToString,
            algorithm__computation__pb2.AlgorithmComputationCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def run(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmComputationApi/run',
            algorithm__computation__pb2.AlgorithmComputationRunRequest.SerializeToString,
            algorithm__computation__pb2.AlgorithmComputationRunResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmComputationApi/get',
            algorithm__computation__pb2.AlgorithmComputationGetRequest.SerializeToString,
            algorithm__computation__pb2.AlgorithmComputationGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.AlgorithmComputationApi/list',
            algorithm__computation__pb2.AlgorithmComputationListRequest.SerializeToString,
            algorithm__computation__pb2.AlgorithmComputationListResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OrderRecommendation(_message.Message):
    __slots__ = ("id", "creator", "justification", "team", "contact_info", "expiration", "created_on")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    JUSTIFICATION_FIELD_NUMBER: _ClassVar[int]
    TEAM_FIELD_NUMBER: _ClassVar[int]
    CONTACT_INFO_FIELD_NUMBER: _ClassVar[int]
    EXPIRATION_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    id: str
    creator: str
    justification: str
    team: str
    contact_info: str
    expiration: _timestamp_pb2.Timestamp
    created_on: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., creator: _Optional[str] = ..., justification: _Optional[str] = ..., team: _Optional[str] = ..., contact_info: _Optional[str] = ..., expiration: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class OrderRecommendationCreateRequest(_message.Message):
    __slots__ = ("order_id", "justification", "team", "contact_info", "expiration")
    ORDER_ID_FIELD_NUMBER: _ClassVar[int]
    JUSTIFICATION_FIELD_NUMBER: _ClassVar[int]
    TEAM_FIELD_NUMBER: _ClassVar[int]
    CONTACT_INFO_FIELD_NUMBER: _ClassVar[int]
    EXPIRATION_FIELD_NUMBER: _ClassVar[int]
    order_id: str
    justification: str
    team: str
    contact_info: str
    expiration: _timestamp_pb2.Timestamp
    def __init__(self, order_id: _Optional[str] = ..., justification: _Optional[str] = ..., team: _Optional[str] = ..., contact_info: _Optional[str] = ..., expiration: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class OrderRecommendationCreateResponse(_message.Message):
    __slots__ = ("status_code", "order_recommendation")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ORDER_RECOMMENDATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    order_recommendation: OrderRecommendation
    def __init__(self, status_code: _Optional[int] = ..., order_recommendation: _Optional[_Union[OrderRecommendation, _Mapping]] = ...) -> None: ...

class OrderRecommendationUpdateRequest(_message.Message):
    __slots__ = ("order_recommendation_id", "justification", "team", "contact_info", "expiration")
    ORDER_RECOMMENDATION_ID_FIELD_NUMBER: _ClassVar[int]
    JUSTIFICATION_FIELD_NUMBER: _ClassVar[int]
    TEAM_FIELD_NUMBER: _ClassVar[int]
    CONTACT_INFO_FIELD_NUMBER: _ClassVar[int]
    EXPIRATION_FIELD_NUMBER: _ClassVar[int]
    order_recommendation_id: str
    justification: str
    team: str
    contact_info: str
    expiration: _timestamp_pb2.Timestamp
    def __init__(self, order_recommendation_id: _Optional[str] = ..., justification: _Optional[str] = ..., team: _Optional[str] = ..., contact_info: _Optional[str] = ..., expiration: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class OrderRecommendationUpdateResponse(_message.Message):
    __slots__ = ("status_code", "order_recommendation")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ORDER_RECOMMENDATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    order_recommendation: OrderRecommendation
    def __init__(self, status_code: _Optional[int] = ..., order_recommendation: _Optional[_Union[OrderRecommendation, _Mapping]] = ...) -> None: ...

class OrderRecommendationDeleteRequest(_message.Message):
    __slots__ = ("order_recommendation_id",)
    ORDER_RECOMMENDATION_ID_FIELD_NUMBER: _ClassVar[int]
    order_recommendation_id: str
    def __init__(self, order_recommendation_id: _Optional[str] = ...) -> None: ...

class OrderRecommendationDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project_filter.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'project_filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import filter_pb2 as filter__pb2
try:
  common__models__pb2 = filter__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = filter__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.filter_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14project_filter.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x0c\x66ilter.proto\"s\n\rProjectFilter\x12\x1f\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0f.oi.papi.Filter\x12\x1a\n\x12\x61nalysis_config_id\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\"T\n!ProjectFilterMappingCreateRequest\x12/\n\x0fproject_filters\x18\x01 \x03(\x0b\x32\x16.oi.papi.ProjectFilter\"9\n\"ProjectFilterMappingCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"T\n!ProjectFilterMappingDeleteRequest\x12/\n\x0fproject_filters\x18\x01 \x03(\x0b\x32\x16.oi.papi.ProjectFilter\"9\n\"ProjectFilterMappingDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xe8\x01\n\x10ProjectFilterApi\x12i\n\x0e\x63reate_mapping\x12*.oi.papi.ProjectFilterMappingCreateRequest\x1a+.oi.papi.ProjectFilterMappingCreateResponse\x12i\n\x0e\x64\x65lete_mapping\x12*.oi.papi.ProjectFilterMappingDeleteRequest\x1a+.oi.papi.ProjectFilterMappingDeleteResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTFILTER']._serialized_start=68
  _globals['_PROJECTFILTER']._serialized_end=183
  _globals['_PROJECTFILTERMAPPINGCREATEREQUEST']._serialized_start=185
  _globals['_PROJECTFILTERMAPPINGCREATEREQUEST']._serialized_end=269
  _globals['_PROJECTFILTERMAPPINGCREATERESPONSE']._serialized_start=271
  _globals['_PROJECTFILTERMAPPINGCREATERESPONSE']._serialized_end=328
  _globals['_PROJECTFILTERMAPPINGDELETEREQUEST']._serialized_start=330
  _globals['_PROJECTFILTERMAPPINGDELETEREQUEST']._serialized_end=414
  _globals['_PROJECTFILTERMAPPINGDELETERESPONSE']._serialized_start=416
  _globals['_PROJECTFILTERMAPPINGDELETERESPONSE']._serialized_end=473
  _globals['_PROJECTFILTERAPI']._serialized_start=476
  _globals['_PROJECTFILTERAPI']._serialized_end=708
# @@protoc_insertion_point(module_scope)



"""
A setuptools based setup module.
Based on:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

import sys

import yaml
import setuptools  # type: ignore


def get_version(version_file_loc):
    with open(version_file_loc, 'r') as stream:
        data = yaml.load(stream, yaml.SafeLoader)
        return (data.get('version'))


def inject_custom_repository(repository_name):
    blacklist = ['register', 'upload']
    inject_arg = '--repository=%s' % (repository_name)

    for command in blacklist:
        try:
            index = sys.argv.index(command)
        except ValueError:
            continue

        sys.argv.insert(index + 1, inject_arg)


inject_custom_repository('orbital')

EXCLUDE_FILES = []

setuptools.setup(
    name='terrascope-api',
    version=get_version('ops/conda-recipe/conda_build_config.yaml'),
    description='Terrascope API Client',
    url='https://github.com/orbitalinsight/oi_papi',
    package_dir={'': 'src/py'},
    packages=setuptools.find_packages('src/py', exclude=[
        'mocked_services',
        'oi_papi',
        'oi_papi.*'
    ]),
    install_requires=['grpcio', 'grpcio-status', 'requests']
)



from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PingRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PingResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class PingRequestServerStreaming(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PingResponseServerStreaming(_message.Message):
    __slots__ = ("status_code", "count")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    count: int
    def __init__(self, status_code: _Optional[int] = ..., count: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: algorithm_computation_execution.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'algorithm_computation_execution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%algorithm_computation_execution.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"\xb4\x05\n\x1d\x41lgorithmComputationExecution\x12\n\n\x02id\x18\x05 \x01(\t\x12\x16\n\x0e\x63omputation_id\x18\x01 \x01(\t\x12,\n\x08start_ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tfinish_ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fpartial_results\x18\x04 \x01(\x08\x12Z\n\x06status\x18\x06 \x01(\x0e\x32J.oi.papi.AlgorithmComputationExecution.AlgorithmComputationExecutionStatus\x12.\n\ncreated_on\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x12validation_details\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tinput_ids\x18\t \x03(\t\"\xa4\x02\n#AlgorithmComputationExecutionStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03NEW\x10\x01\x12\x17\n\x13PERMISSION_CHECKING\x10\x02\x12\x1e\n\x1aPERMISSION_CHECK_SUCCEEDED\x10\x03\x12\x1b\n\x17PERMISSION_CHECK_FAILED\x10\x04\x12\x0e\n\nVALIDATING\x10\x05\x12\x18\n\x14VALIDATION_SUCCEEDED\x10\x06\x12\x15\n\x11VALIDATION_FAILED\x10\x07\x12\x0b\n\x07RUNNING\x10\x08\x12\r\n\tSUCCEEDED\x10\t\x12\n\n\x06\x46\x41ILED\x10\n\x12\x0b\n\x07STOPPED\x10\x0b\x12\r\n\tCANCELLED\x10\x0c\x12\x0c\n\x08RETRYING\x10\r\"_\n\'AlgorithmComputationExecutionGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"\xba\x01\n(AlgorithmComputationExecutionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12P\n algorithm_computation_executions\x18\x02 \x03(\x0b\x32&.oi.papi.AlgorithmComputationExecution\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\x8e\x01\n AlgorithmComputationExecutionApi\x12j\n\x03get\x12\x30.oi.papi.AlgorithmComputationExecutionGetRequest\x1a\x31.oi.papi.AlgorithmComputationExecutionGetResponseP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'algorithm_computation_execution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ALGORITHMCOMPUTATIONEXECUTION']._serialized_start=135
  _globals['_ALGORITHMCOMPUTATIONEXECUTION']._serialized_end=827
  _globals['_ALGORITHMCOMPUTATIONEXECUTION_ALGORITHMCOMPUTATIONEXECUTIONSTATUS']._serialized_start=535
  _globals['_ALGORITHMCOMPUTATIONEXECUTION_ALGORITHMCOMPUTATIONEXECUTIONSTATUS']._serialized_end=827
  _globals['_ALGORITHMCOMPUTATIONEXECUTIONGETREQUEST']._serialized_start=829
  _globals['_ALGORITHMCOMPUTATIONEXECUTIONGETREQUEST']._serialized_end=924
  _globals['_ALGORITHMCOMPUTATIONEXECUTIONGETRESPONSE']._serialized_start=927
  _globals['_ALGORITHMCOMPUTATIONEXECUTIONGETRESPONSE']._serialized_end=1113
  _globals['_ALGORITHMCOMPUTATIONEXECUTIONAPI']._serialized_start=1116
  _globals['_ALGORITHMCOMPUTATIONEXECUTIONAPI']._serialized_end=1258
# @@protoc_insertion_point(module_scope)



import common_models_pb2 as _common_models_pb2
import resource_pb2 as _resource_pb2
import common_models_pb2 as _common_models_pb2_1
import subject_pb2 as _subject_pb2
import subject_pb2 as _subject_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from resource_pb2 import ResourceRegisterTypeRequest as ResourceRegisterTypeRequest
from resource_pb2 import ResourceRegisterTypeResponse as ResourceRegisterTypeResponse
from resource_pb2 import ResourceTypesListRequest as ResourceTypesListRequest
from resource_pb2 import ResourceTypesListResponse as ResourceTypesListResponse
from resource_pb2 import Resource as Resource
from resource_pb2 import ResourceCreateRequest as ResourceCreateRequest
from resource_pb2 import ResourceCreateResponse as ResourceCreateResponse
from resource_pb2 import ResourceListRequest as ResourceListRequest
from resource_pb2 import ResourceListResponse as ResourceListResponse
from subject_pb2 import Subject as Subject

DESCRIPTOR: _descriptor.FileDescriptor

class Permission(_message.Message):
    __slots__ = ("subjects", "permission_types", "resources")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PERMISSION_TYPE_UNKNOWN: _ClassVar[Permission.Type]
        READ: _ClassVar[Permission.Type]
        WRITE: _ClassVar[Permission.Type]
        ADMIN: _ClassVar[Permission.Type]
        EXECUTE: _ClassVar[Permission.Type]
        ORDER: _ClassVar[Permission.Type]
        ORDER_APPROVER: _ClassVar[Permission.Type]
    PERMISSION_TYPE_UNKNOWN: Permission.Type
    READ: Permission.Type
    WRITE: Permission.Type
    ADMIN: Permission.Type
    EXECUTE: Permission.Type
    ORDER: Permission.Type
    ORDER_APPROVER: Permission.Type
    SUBJECTS_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_TYPES_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    subjects: _containers.RepeatedCompositeFieldContainer[_subject_pb2_1.Subject]
    permission_types: _containers.RepeatedScalarFieldContainer[Permission.Type]
    resources: _containers.RepeatedCompositeFieldContainer[_resource_pb2.Resource]
    def __init__(self, subjects: _Optional[_Iterable[_Union[_subject_pb2_1.Subject, _Mapping]]] = ..., permission_types: _Optional[_Iterable[_Union[Permission.Type, str]]] = ..., resources: _Optional[_Iterable[_Union[_resource_pb2.Resource, _Mapping]]] = ...) -> None: ...

class PermissionCreateRequest(_message.Message):
    __slots__ = ("permissions",)
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    permissions: _containers.RepeatedCompositeFieldContainer[Permission]
    def __init__(self, permissions: _Optional[_Iterable[_Union[Permission, _Mapping]]] = ...) -> None: ...

class PermissionCreateResponse(_message.Message):
    __slots__ = ("status_code", "message")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    message: str
    def __init__(self, status_code: _Optional[int] = ..., message: _Optional[str] = ...) -> None: ...

class PermissionDeleteRequest(_message.Message):
    __slots__ = ("permissions",)
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    permissions: _containers.RepeatedCompositeFieldContainer[Permission]
    def __init__(self, permissions: _Optional[_Iterable[_Union[Permission, _Mapping]]] = ...) -> None: ...

class PermissionDeleteResponse(_message.Message):
    __slots__ = ("status_code", "message")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    message: str
    def __init__(self, status_code: _Optional[int] = ..., message: _Optional[str] = ...) -> None: ...

class PermissionGetRequest(_message.Message):
    __slots__ = ("resources", "permission_type", "subject")
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_TYPE_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    resources: _containers.RepeatedCompositeFieldContainer[_resource_pb2.Resource]
    permission_type: Permission.Type
    subject: _subject_pb2_1.Subject
    def __init__(self, resources: _Optional[_Iterable[_Union[_resource_pb2.Resource, _Mapping]]] = ..., permission_type: _Optional[_Union[Permission.Type, str]] = ..., subject: _Optional[_Union[_subject_pb2_1.Subject, _Mapping]] = ...) -> None: ...

class PermissionGetResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class PermissionListRequest(_message.Message):
    __slots__ = ("resources", "permission_types", "subject")
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_TYPES_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    resources: _containers.RepeatedCompositeFieldContainer[_resource_pb2.Resource]
    permission_types: _containers.RepeatedScalarFieldContainer[Permission.Type]
    subject: _subject_pb2_1.Subject
    def __init__(self, resources: _Optional[_Iterable[_Union[_resource_pb2.Resource, _Mapping]]] = ..., permission_types: _Optional[_Iterable[_Union[Permission.Type, str]]] = ..., subject: _Optional[_Union[_subject_pb2_1.Subject, _Mapping]] = ...) -> None: ...

class PermissionList(_message.Message):
    __slots__ = ("permission_type", "resources")
    PERMISSION_TYPE_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    permission_type: Permission.Type
    resources: _containers.RepeatedCompositeFieldContainer[_resource_pb2.Resource]
    def __init__(self, permission_type: _Optional[_Union[Permission.Type, str]] = ..., resources: _Optional[_Iterable[_Union[_resource_pb2.Resource, _Mapping]]] = ...) -> None: ...

class PermissionListResponse(_message.Message):
    __slots__ = ("status_code", "permission_and_resources")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_AND_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    permission_and_resources: _containers.RepeatedCompositeFieldContainer[PermissionList]
    def __init__(self, status_code: _Optional[int] = ..., permission_and_resources: _Optional[_Iterable[_Union[PermissionList, _Mapping]]] = ...) -> None: ...

class PermissionSystemMetadata(_message.Message):
    __slots__ = ("resource_types_metadata", "permission_types_metadata", "resource_permissions")
    class ResourceTypeMetadata(_message.Message):
        __slots__ = ("name", "display_name", "description", "ord")
        NAME_FIELD_NUMBER: _ClassVar[int]
        DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        ORD_FIELD_NUMBER: _ClassVar[int]
        name: str
        display_name: str
        description: str
        ord: int
        def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., ord: _Optional[int] = ...) -> None: ...
    class PermissionTypeMetadata(_message.Message):
        __slots__ = ("name", "display_name", "description", "ord")
        NAME_FIELD_NUMBER: _ClassVar[int]
        DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        ORD_FIELD_NUMBER: _ClassVar[int]
        name: str
        display_name: str
        description: str
        ord: int
        def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., ord: _Optional[int] = ...) -> None: ...
    class ResourcePermission(_message.Message):
        __slots__ = ("resource_type", "permission_type", "description")
        RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
        PERMISSION_TYPE_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        resource_type: str
        permission_type: str
        description: str
        def __init__(self, resource_type: _Optional[str] = ..., permission_type: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...
    RESOURCE_TYPES_METADATA_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_TYPES_METADATA_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    resource_types_metadata: _containers.RepeatedCompositeFieldContainer[PermissionSystemMetadata.ResourceTypeMetadata]
    permission_types_metadata: _containers.RepeatedCompositeFieldContainer[PermissionSystemMetadata.PermissionTypeMetadata]
    resource_permissions: _containers.RepeatedCompositeFieldContainer[PermissionSystemMetadata.ResourcePermission]
    def __init__(self, resource_types_metadata: _Optional[_Iterable[_Union[PermissionSystemMetadata.ResourceTypeMetadata, _Mapping]]] = ..., permission_types_metadata: _Optional[_Iterable[_Union[PermissionSystemMetadata.PermissionTypeMetadata, _Mapping]]] = ..., resource_permissions: _Optional[_Iterable[_Union[PermissionSystemMetadata.ResourcePermission, _Mapping]]] = ...) -> None: ...

class PermissionGetMetadataRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PermissionGetMetadataResponse(_message.Message):
    __slots__ = ("status_code", "metadata")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    metadata: PermissionSystemMetadata
    def __init__(self, status_code: _Optional[int] = ..., metadata: _Optional[_Union[PermissionSystemMetadata, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: forgot_password.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'forgot_password.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x66orgot_password.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"/\n\x19UserForgotPasswordRequest\x12\x12\n\nuser_email\x18\x01 \x01(\t\"1\n\x1aUserForgotPasswordResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2o\n\x11\x46orgotPasswordApi\x12Z\n\x0f\x66orgot_password\x12\".oi.papi.UserForgotPasswordRequest\x1a#.oi.papi.UserForgotPasswordResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'forgot_password_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_USERFORGOTPASSWORDREQUEST']._serialized_start=55
  _globals['_USERFORGOTPASSWORDREQUEST']._serialized_end=102
  _globals['_USERFORGOTPASSWORDRESPONSE']._serialized_start=104
  _globals['_USERFORGOTPASSWORDRESPONSE']._serialized_end=153
  _globals['_FORGOTPASSWORDAPI']._serialized_start=155
  _globals['_FORGOTPASSWORDAPI']._serialized_end=266
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProviderQuotasListRequest(_message.Message):
    __slots__ = ("provider",)
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    provider: str
    def __init__(self, provider: _Optional[str] = ...) -> None: ...

class ProviderQuota(_message.Message):
    __slots__ = ("data_source_id", "quota_name", "used", "limit", "unit")
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    QUOTA_NAME_FIELD_NUMBER: _ClassVar[int]
    USED_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    quota_name: str
    used: float
    limit: float
    unit: str
    def __init__(self, data_source_id: _Optional[str] = ..., quota_name: _Optional[str] = ..., used: _Optional[float] = ..., limit: _Optional[float] = ..., unit: _Optional[str] = ...) -> None: ...

class ProviderQuotasListResponse(_message.Message):
    __slots__ = ("quotas",)
    QUOTAS_FIELD_NUMBER: _ClassVar[int]
    quotas: _containers.RepeatedCompositeFieldContainer[ProviderQuota]
    def __init__(self, quotas: _Optional[_Iterable[_Union[ProviderQuota, _Mapping]]] = ...) -> None: ...



import common_models_pb2 as _common_models_pb2
import project_pb2 as _project_pb2
import common_models_pb2 as _common_models_pb2_1
import analysis_config_pb2 as _analysis_config_pb2
import analysis_computation_pb2 as _analysis_computation_pb2
import aoi_collection_pb2 as _aoi_collection_pb2
import result_pb2 as _result_pb2
import project_filter_pb2 as _project_filter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from project_pb2 import Project as Project
from project_pb2 import ProjectListRequest as ProjectListRequest
from project_pb2 import ProjectListResponse as ProjectListResponse
from project_pb2 import ProjectGetRequest as ProjectGetRequest
from project_pb2 import ProjectGetResponse as ProjectGetResponse
from project_pb2 import ProjectCreateRequest as ProjectCreateRequest
from project_pb2 import ProjectCreateResponse as ProjectCreateResponse
from project_pb2 import ProjectUpdateRequest as ProjectUpdateRequest
from project_pb2 import ProjectUpdateResponse as ProjectUpdateResponse
from project_pb2 import ProjectDeleteRequest as ProjectDeleteRequest
from project_pb2 import ProjectDeleteResponse as ProjectDeleteResponse
from project_pb2 import ProjectRunRequest as ProjectRunRequest
from project_pb2 import ProjectRunResponse as ProjectRunResponse
from project_pb2 import ProjectCloneRequest as ProjectCloneRequest
from project_pb2 import ProjectCloneResponse as ProjectCloneResponse
from project_pb2 import ProjectCreditEstimateRequest as ProjectCreditEstimateRequest
from project_pb2 import ProjectCreditEstimateResponse as ProjectCreditEstimateResponse
from project_pb2 import ProjectRequestAccessRequest as ProjectRequestAccessRequest
from project_pb2 import ProjectRequestAccessResponse as ProjectRequestAccessResponse

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectGroup(_message.Message):
    __slots__ = ("id", "name", "projects", "collapsed", "sort_order")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    COLLAPSED_FIELD_NUMBER: _ClassVar[int]
    SORT_ORDER_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    projects: _containers.RepeatedCompositeFieldContainer[_project_pb2.Project]
    collapsed: bool
    sort_order: int
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., projects: _Optional[_Iterable[_Union[_project_pb2.Project, _Mapping]]] = ..., collapsed: bool = ..., sort_order: _Optional[int] = ...) -> None: ...

class ProjectGroupListRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class ProjectGroupListResponse(_message.Message):
    __slots__ = ("status_code", "project_groups", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    project_groups: _containers.RepeatedCompositeFieldContainer[ProjectGroup]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., project_groups: _Optional[_Iterable[_Union[ProjectGroup, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class ProjectGroupCreateRequest(_message.Message):
    __slots__ = ("name", "project_ids")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_IDS_FIELD_NUMBER: _ClassVar[int]
    name: str
    project_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., project_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ProjectGroupCreateResponse(_message.Message):
    __slots__ = ("status_code", "project_group")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_GROUP_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    project_group: ProjectGroup
    def __init__(self, status_code: _Optional[int] = ..., project_group: _Optional[_Union[ProjectGroup, _Mapping]] = ...) -> None: ...

class ProjectGroupDeleteRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ProjectGroupDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ProjectGroupUpdateRequest(_message.Message):
    __slots__ = ("project_groups", "update_projects", "update_details")
    PROJECT_GROUPS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_PROJECTS_FIELD_NUMBER: _ClassVar[int]
    UPDATE_DETAILS_FIELD_NUMBER: _ClassVar[int]
    project_groups: _containers.RepeatedCompositeFieldContainer[ProjectGroup]
    update_projects: bool
    update_details: bool
    def __init__(self, project_groups: _Optional[_Iterable[_Union[ProjectGroup, _Mapping]]] = ..., update_projects: bool = ..., update_details: bool = ...) -> None: ...

class ProjectGroupUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...
